# Setup

## Home Assistant Add-on

If you have Home Assistant OS or Supervised, you can install the app via the community add-ons repo.

Find the docs [here](https://github.com/hassio-addons/addon-home-panel#readme)

## Docker Compose

---

- Install [Docker](https://www.docker.com/community-edition) and
 [Docker Compose](https://docs.docker.com/compose/install/)
- Create a directory for your compose file. For example, `home-panel`
- Create a `docker-compose.yml` file:

### SSL

!!! info ""
    This example maps the `ssl` directory in the home directory.
    Inside this directory are two files `fullchain.pem` and `privkey.pem`
    which are files generated by [Let's Encrypt](https://letsencrypt.org/).
    Change the environment variables to your own Home Assistant details

```yaml
---
version: '3'

services:
  home-panel:
    image: timmo001/home-panel
    environment:
      SSL_CERTFILE: fullchain.pem
      SSL_KEYFILE: privkey.pem
    ports:
      - 8234:8234
    volumes:
      - home_panel_data:/data
      - ~/ssl/fullchain.pem:/data/ssl/fullchain.pem
      - ~/ssl/privkey.pem:/data/ssl/privkey.pem

volumes:
  home_panel_data: {}
```

### Non-SSL

!!! warning ""
    This example shows how to set up the app without ssl. This is useful for
     testing, but is **unsecure**, so don't expose the app to the outside
     world.

```yaml
---
version: '3'

services:
  home-panel:
    image: timmo001/home-panel
    ports:
      - 8234:8234
    volumes:
      - home_panel_data:/data

volumes:
  home_panel_data: {}
```

## Docker

---

- Install [Docker](https://www.docker.com/community-edition)
- Create volume

```bash
docker volume create home_panel_data
```

- Run image

### SSL

!!! info ""
    This example maps the `ssl` directory in the home directory.
    Inside this directory are two files `fullchain.pem` and `privkey.pem`
    which are files generated by [Let's Encrypt](https://letsencrypt.org/).
    Change the environment variables to your own Home Assistant details

```bash
docker run -d \
  -p 8234:8234 \
  -v home_panel_data:/data \
  -v ~/ssl/fullchain.pem:/data/ssl/fullchain.pem \
  -v ~/ssl/privkey.pem:/data/ssl/privkey.pem \
  -e SSL_CERTFILE=fullchain.pem \
  -e SSL_KEYFILE=privkey.pem \
  timmo001/home-panel
```

### Non-SSL

!!! warning ""
    This example shows how to set up the app without ssl. This is useful for
     testing, but is **unsecure**, so don't expose the app to the outside
     world.

```bash
docker run -d \
  -v home_panel_data:/data \
  -p 8234:8234 \
  timmo001/home-panel
```

### Development

---

!!! warning ""
    **This option is not secure. Do not open to the outside world!**

- Run the app

```bash
yarn install
yarn start
```

- Open another session and run the API

```bash
cd api
yarn install
yarn start
```

- The app should open in your default browser under [http://localhost:3000](http://localhost:3000)
